# Korean Tokenizer

# References
1. https://github.com/hyunwoongko/kss
2. https://github.com/likejazz/korean-sentence-splitter
3. https://github.com/open-korean-text/open-korean-text
4. https://github.com/jeongukjae/korean-spacing-model
5. https://littlefoxdiary.tistory.com/42
6. https://github.com/bab2min/kiwipiepy
7. http://semantics.kr/%ED%95%9C%EA%B5%AD%EC%96%B4-%ED%98%95%ED%83%9C%EC%86%8C-%EB%B6%84%EC%84%9D%EA%B8%B0-%EB%B3%84-%EB%AC%B8%EC%9E%A5-%EB%B6%84%EB%A6%AC-%EC%84%B1%EB%8A%A5%EB%B9%84%EA%B5%90/
8. https://bab2min.tistory.com/669
9. https://github.com/songys/AwesomeKorean_Data
10. https://github.com/kakao/khaiii/wiki/CNN-%EB%AA%A8%EB%8D%B8
